@@ -28,7 +28,7 @@
    The GNU General Public License is contained in the file COPYING.
 */
 
-/* Copyright 2013-2015, Ivo Raisr <ivosh@ivosh.net> */
+/* Copyright 2013-2016, Ivo Raisr <ivosh@ivosh.net> */
 
 /* Copyright 2013, OmniTI Computer Consulting, Inc. All rights reserved. */
 
@@ -70,6 +70,7 @@
 
 #include <sys/types.h>
 #define VKI_UINT_MAX UINT_MAX
+#define VKI_UINTPTR_MAX UINTPTR_MAX
 #define vki_boolean_t boolean_t
 #define vki_datalink_id_t datalink_id_t
 #define vki_uint_t uint_t
@@ -132,7 +133,10 @@ typedef uint32_t vki_u32;
 #define VKI_A_GETPINFO_ADDR A_GETPINFO_ADDR
 #define VKI_A_GETPOLICY A_GETPOLICY
 #define VKI_A_GETQCTRL A_GETQCTRL
+#if defined(SOLARIS_AUDITON_STAT)
 #define VKI_A_GETSTAT A_GETSTAT
+#define VKI_A_SETSTAT A_SETSTAT
+#endif /* SOLARIS_AUDITON_STAT */
 #define VKI_A_SETAMASK A_SETAMASK
 #define VKI_A_SETCLASS A_SETCLASS
 #define VKI_A_SETCOND A_SETCOND
@@ -142,7 +146,6 @@ typedef uint32_t vki_u32;
 #define VKI_A_SETPOLICY A_SETPOLICY
 #define VKI_A_SETQCTRL A_SETQCTRL
 #define VKI_A_SETSMASK A_SETSMASK
-#define VKI_A_SETSTAT A_SETSTAT
 #define VKI_A_SETUMASK A_SETUMASK
 #define VKI_BSM_AUDIT BSM_AUDIT
 #define VKI_BSM_AUDITCTL BSM_AUDITCTL
@@ -157,11 +160,13 @@ typedef uint32_t vki_u32;
 #define vki_au_id_t au_id_t
 #define vki_au_mask_t au_mask_t
 #define vki_au_qctrl au_qctrl
-#define vki_au_stat_t au_stat_t
 #define vki_auditinfo_t auditinfo_t
 #define vki_auditinfo_addr_t auditinfo_addr_t
 #define vki_auditpinfo auditpinfo
 #define vki_auditpinfo_addr auditpinfo_addr
+#if defined(SOLARIS_AUDITON_STAT)
+#define vki_au_stat_t au_stat_t
+#endif /* SOLARIS_AUDITON_STAT */
 
 
 #include <sys/psw.h>
@@ -202,7 +207,11 @@ typedef struct {
 
 
 #include <net/if.h>
+#define vki_ifconf ifconf
+#define vki_ifreq ifreq
+#define vki_lifconf lifconf
 #define vki_lifnum lifnum
+#define vki_lifreq lifreq
 
 
 #include <netinet/in.h>
@@ -248,10 +257,17 @@ typedef struct {
 #define VKI_AT_PAGESZ AT_PAGESZ
 #define VKI_AT_BASE AT_BASE
 #define VKI_AT_FLAGS AT_FLAGS
+#define VKI_AT_ENTRY AT_ENTRY
 #define VKI_AT_SUN_PLATFORM AT_SUN_PLATFORM
 #define VKI_AT_SUN_HWCAP AT_SUN_HWCAP
 #define VKI_AT_SUN_EXECNAME AT_SUN_EXECNAME
 #define VKI_AT_SUN_AUXFLAGS AT_SUN_AUXFLAGS
+#if defined(SOLARIS_RESERVE_SYSSTAT_ADDR)
+#define VKI_AT_SUN_SYSSTAT_ADDR AT_SUN_SYSSTAT_ADDR
+#endif
+#if defined(SOLARIS_RESERVE_SYSSTAT_ZONE_ADDR)
+#define VKI_AT_SUN_SYSSTAT_ZONE_ADDR AT_SUN_SYSSTAT_ZONE_ADDR
+#endif
 
 #define VKI_AF_SUN_HWCAPVERIFY AF_SUN_HWCAPVERIFY
 
@@ -329,6 +345,12 @@ typedef struct vki_kcf_door_arg_s {
 #define vki_crypto_get_provider_list_t crypto_get_provider_list_t
 
 
+#include <sys/dditypes.h>
+#include <sys/devinfo_impl.h>
+#define VKI_DINFOUSRLD DINFOUSRLD
+#define VKI_DINFOIDENT DINFOIDENT
+
+
 #include <sys/dirent.h>
 #define VKI_MAXGETDENTS_SIZE MAXGETDENTS_SIZE
 #define vki_dirent dirent
@@ -461,6 +483,10 @@ typedef struct vki_kcf_door_arg_s {
 #endif /* SOLARIS_EXECVE_SYSCALL_TAKES_FLAGS */
 
 
+#include <sys/fasttrap.h>
+#define VKI_PT_SUNWDTRACE_SIZE PT_SUNWDTRACE_SIZE
+
+
 #include <sys/fcntl.h>
 #define VKI_O_RDONLY O_RDONLY
 #define VKI_O_WRONLY O_WRONLY
@@ -548,6 +574,13 @@ typedef struct vki_kcf_door_arg_s {
 #define vki_namefd namefd
 
 
+#include <sys/fstyp.h>
+#define VKI_FSTYPSZ FSTYPSZ
+#define VKI_GETFSIND GETFSIND
+#define VKI_GETFSTYP GETFSTYP
+#define VKI_GETNFSTYP GETNFSTYP
+
+
 #include <sys/ioccom.h>
 #define _VKI_IOC_DIR(x) ((x) & (IOC_VOID | IOC_OUT | IOC_IN))
 #define _VKI_IOC_SIZE(x) (((x) >> 16) & IOCPARM_MASK)
@@ -570,6 +603,10 @@ typedef struct vki_kcf_door_arg_s {
 #define vki_semid64_ds semid_ds64
 
 
+#include <sys/loadavg.h>
+#define VKI_LOADAVG_NSTATS LOADAVG_NSTATS
+
+
 #include <sys/lwp.h>
 #define VKI_LWP_DAEMON LWP_DAEMON
 #define VKI_LWP_FSBASE _LWP_FSBASE
@@ -607,14 +644,34 @@ typedef struct vki_kcf_door_arg_s {
 
 
 #include <sys/mntio.h>
+#define VKI_MNTIOC_GETEXTMNTENT MNTIOC_GETEXTMNTENT
 #define VKI_MNTIOC_GETMNTANY MNTIOC_GETMNTANY
 
 
 #include <sys/mnttab.h>
+#define vki_extmnttab extmnttab
 #define vki_mntentbuf mntentbuf
 #define vki_mnttab mnttab
 
 
+#include <sys/modctl.h>
+#define VKI_MODLOAD MODLOAD
+#define VKI_MODUNLOAD MODUNLOAD
+#define VKI_MODINFO MODINFO
+
+#if defined(SOLARIS_MODCTL_MODNVL)
+#define VKI_MODNVL_DEVLINKSYNC MODNVL_DEVLINKSYNC
+#define VKI_MODDEVINFO_CACHE_TS MODDEVINFO_CACHE_TS
+#if !defined(HAVE_SYS_SYSNVL_H)
+#define VKI_MODCTL_NVL_OP_GET MODCTL_NVL_OP_GET
+#define VKI_MODCTL_NVL_OP_UPDATE MODCTL_NVL_OP_UPDATE
+#endif /* !HAVE_SYS_SYSNVL_H */
+#endif /* SOLARIS_MODCTL_MODNVL */
+
+#define vki_modid_t int
+#define vki_modinfo modinfo
+
+
 #include <sys/mount.h>
 #define	VKI_MS_DATA MS_DATA
 #define	VKI_MS_OPTIONSTR MS_OPTIONSTR
@@ -759,6 +816,24 @@ typedef struct vki_kcf_door_arg_s {
 #define vki_procset_t procset_t
 
 
+#include <sys/pset.h>
+#define VKI_PSET_CREATE PSET_CREATE
+#define VKI_PSET_DESTROY PSET_DESTROY
+#define VKI_PSET_ASSIGN PSET_ASSIGN
+#define VKI_PSET_INFO PSET_INFO
+#define VKI_PSET_BIND PSET_BIND
+#define VKI_PSET_GETLOADAVG PSET_GETLOADAVG
+#define VKI_PSET_LIST PSET_LIST
+#define VKI_PSET_SETATTR PSET_SETATTR
+#define VKI_PSET_GETATTR PSET_GETATTR
+#define VKI_PSET_ASSIGN_FORCED PSET_ASSIGN_FORCED
+#define VKI_PSET_BIND_LWP PSET_BIND_LWP
+#if defined(SOLARIS_PSET_GET_NAME)
+#define VKI_PSET_GET_NAME PSET_GET_NAME
+#endif /* SOLARIS_PSET_GET_NAME */
+#define vki_psetid_t psetid_t
+
+
 #include <sys/regset.h>
 #define vki_prgregset_t prgregset_t
 
@@ -1055,6 +1130,14 @@ typedef struct sigaction vki_sigaction_fromK_t;
 
 
 #include <sys/sockio.h>
+#define VKI_SIOCGIFCONF SIOCGIFCONF
+#define VKI_SIOCGIFFLAGS SIOCGIFFLAGS
+#define VKI_SIOCGIFNETMASK SIOCGIFNETMASK
+#define VKI_SIOCGIFNUM SIOCGIFNUM
+#define VKI_SIOCGLIFBRDADDR SIOCGLIFBRDADDR
+#define VKI_SIOCGLIFCONF SIOCGLIFCONF
+#define VKI_SIOCGLIFFLAGS SIOCGLIFFLAGS
+#define VKI_SIOCGLIFNETMASK SIOCGLIFNETMASK
 #define VKI_SIOCGLIFNUM SIOCGLIFNUM
 
 
@@ -1124,6 +1207,8 @@ typedef struct sigaction vki_sigaction_fromK_t;
 
 #include <sys/stropts.h>
 #define VKI_I_CANPUT I_CANPUT
+#define VKI_I_FIND I_FIND
+#define VKI_I_FLUSH I_FLUSH
 #define VKI_I_PEEK I_PEEK
 #define VKI_I_PUSH I_PUSH
 #define VKI_I_STR I_STR
@@ -1168,6 +1253,13 @@ typedef struct sigaction vki_sigaction_fromK_t;
 #define VKI_SI86FPSTART SI86FPSTART
 
 
+#if defined(HAVE_SYS_SYSNVL_H)
+#include <sys/sysnvl.h>
+#define VKI_SYSNVL_OP_GET SYSNVL_OP_GET
+#define VKI_SYSNVL_OP_UPDATE SYSNVL_OP_UPDATE
+#endif /* HAVE_SYS_SYSNVL_H */
+
+
 #include <sys/systeminfo.h>
 #define VKI_SI_SYSNAME SI_SYSNAME
 #define VKI_SI_HOSTNAME SI_HOSTNAME
@@ -1396,7 +1488,11 @@ struct sysv_ucontext {
 #error "Unknown platform"
 #endif
 
+#if defined(SOLARIS_FPCHIP_STATE_TAKES_UNDERSCORE)
+#define vki_fpchip_state _fpchip_state
+#else
 #define vki_fpchip_state fpchip_state
+#endif /* SOLARIS_FPCHIP_STATE_TAKES_UNDERSCORE */
 
 #define VKI_GETCONTEXT GETCONTEXT
 #define VKI_SETCONTEXT SETCONTEXT
